@@ -1,5 +1,5 @@
 """Entrypoint to make relevant classes available at the top level."""
 from .youconfigme import AutoConfig, Config, ConfigItemNotFound, ConfigSection
 
-__version__ = '0.6.13'
-__all__ = ['AutoConfig', 'Config', 'ConfigItemNotFound', 'ConfigSection']
+__version__ = "0.8.0"
+__all__ = ["AutoConfig", "Config", "ConfigItemNotFound", "ConfigSection"]
